Augur.Development (augur v0.1.0)
Development service for Augur
Caches all texts being sent from your application in Augur.Cache
config = %Augur.Development{}
Augur.Service.send_text(config, "from", "to", "Hello!") Development service for Augur
Caches all texts being sent from your application in Augur.Cache
config = %Augur.Development{}
Augur.Service.send_text(config, "from", "to", "Hello!")