Augur.Twilio.Exception exception (augur v0.1.0)
Exception for Twilio
If Twilio returns something not 2XX, this exception is generated
body and status are copied directly from the response from Twilio.
code and reason are from Twilio if provided, Twilio has it's own internal
error codes that help debug the problem that was encountered.